@@ -547,6 +547,7 @@ static void TVActionSetStationAction(
     else {
         str = params[0];
 
+        /*  Are we incrementally changing the channel or frequency?  */
         if (( str[0] == '+' ) || ( str[0] == '-' )) {
             if ( toupper( str[1] ) == 'F' )
                 freq_inc = ( str[0] == '-' ? -1 : +1 );
@@ -555,6 +556,14 @@ static void TVActionSetStationAction(
                 if ( chan_inc == 0 )
                     valid = False;
             }
+        } 
+
+        /*  No, so save the channel/freq we're leaving as the last station  */
+        else {
+            if ( s.tuner_chan_active )
+              p->last_chan = s.tuner_chan, p->last_freq = 0.0;
+            else
+              p->last_chan = -1          , p->last_freq = s.tuner_freq;
         }
     }
     if ( !valid ) {
@@ -927,6 +936,8 @@ static void TVActionSetCaptureInputAction(
                 dev = TV_DEVICE_SVIDEO;
             else if ( strncmp( str, "csvideo", strlen("csvideo") ) == 0 )
                 dev = TV_DEVICE_CSVIDEO;
+            else if ( strncmp( str, "dev3", strlen("dev3") ) == 0 )
+                dev = TV_DEVICE_DEV3;
         }
 
         if (( dev_inc == 0 ) && ( dev == (TV_INPUT_DEVICE) -1 ))
@@ -1441,6 +1452,7 @@ void TVActionSetCaptureInput( TV_INPUT_DEVICE dev )
         case TV_DEVICE_VIDEO   : strcpy( str, "video"   );  break;
         case TV_DEVICE_SVIDEO  : strcpy( str, "svideo"  );  break;
         case TV_DEVICE_CSVIDEO : strcpy( str, "csvideo" );  break;
+        case TV_DEVICE_DEV3    : strcpy( str, "dev3"    );  break;
         default               :
              fprintf( stderr, "TVActionSetCaptureInput: Bad arg %d\n",
                       dev );
@@ -1478,6 +1490,50 @@ void TVActionQuit( void )
     TVActionQuitAction( NULL, NULL, NULL, &num_param );
 }
 
+ /**@BEGINFUNC**************************************************************
+ 
+    Prototype  : static void TVActionFlipStationAction(
+                      Widget    wgt,
+                      XEvent   *xevent,
+                      String   *params,
+                      Cardinal *num_params )
+
+    Purpose    : Flip to previously selected station.
+
+    Programmer : 14-Mar-2000  Steve Reid
+
+    Parameters : wgt        - I: <not used>
+                 xevent     - I: <not used>
+                 params     - I: <not used>
+                 num_params - I: should be 0
+
+    Returns    :
+
+    Globals    : None.
+
+ **@ENDFUNC*****************************************************************/
+
+static void TVActionFlipStationAction(
+                Widget    wgt,
+                XEvent   *xevent,
+                String   *params,
+                Cardinal *num_params )
+{
+    TV_PREFS *p = &G_glob.prefs;
+    char      chan_str[ 80 ];
+
+    if ( *num_params > 0 ) {
+        fprintf( stderr, 
+            "TVActionFlipStationAction: Unexpected argument ignored.\n" );
+    }
+
+    if ( p->last_chan >= TV_CHAN_MIN )
+      sprintf( chan_str, "%ld" , p->last_chan );
+    else
+      sprintf( chan_str, "f%f", p->last_freq );
+    TVActionSetStation( chan_str );
+}
+
 /**@BEGINFUNC**************************************************************
 
     Prototype  : void TVActionAddAppActions()
@@ -1507,6 +1563,7 @@ void TVActionAddAppActions()
          { "TVToggleFreeze"     , TVActionToggleFreezeAction      },
          { "TVVideoRecordStart" , TVActionVideoRecordStartAction  },
          { "TVVideoRecordStop"  , TVActionVideoRecordStopAction   },
+         { "TVFlipStation"      , TVActionFlipStationAction       },
          { "TVQuit"             , TVActionQuitAction              },
          { "no-op"              , TVActionNoOp                    }
         };
