@@ -57,7 +57,7 @@
 
 #define AUTOMODE_TIMER_MS 8
 
-#define VOLUME_FMT "Volume: %d%%"
+#define VOLUME_FMT "Volume: %ld%%"
 #define MUTE_STR   "MUTE"
 
 /*#define FNPRINTF(x) printf x*/
@@ -109,8 +109,7 @@ static void TVANNOTLoadFont(
           XFontSet    *fontset )
 {
     char        **fonts;
-    int           count, 
-                  i;
+    int           count;
     char          new_font[ 256 ] = "";
     XFontStruct  *fontstr = NULL;
     char        **missing_charset_list;
@@ -179,7 +178,14 @@ static void TVANNOTLoadFont(
 
     *fontset = XCreateFontSet( TVDISPLAY, new_font, &missing_charset_list, 
                               &missing_count, NULL );
-    assert( *fontset != NULL );
+    if ( ! *fontset ) {
+        fprintf( stderr, 
+          "Whoah!  Failed to load font '%s' which X 'said' it knew about.\n"
+          "This shouldn't happen (but does in XFree86 3.9.16).\n"
+          "Basically, choose another font or take the default font.\n",
+          new_font );
+        exit(1);
+    }
 }
 
 /*---------------------------------------------------------------------------*/
@@ -297,8 +303,6 @@ static void TVANNOTStationPropSetDrawableSize(
                 Dimension      width,
                 Dimension      height )
 {
-    TV_XSCREEN      *s = &G_glob.x;
-    XFontSet         fontset;
     TV_INT32         pixel_size;
     Dimension        vm_width, 
                      vm_height;
@@ -336,7 +340,6 @@ static void TVANNOTTunerModePropSetDrawableSize(
                 Dimension      width,
                 Dimension      height )
 {
-    XFontSet         fontset;
     TV_INT32         pixel_size;
     Dimension        vm_width, 
                      vm_height;
@@ -374,7 +377,6 @@ static void TVANNOTInputDevPropSetDrawableSize(
                 Dimension      width,
                 Dimension      height )
 {
-    XFontSet         fontset;
     TV_INT32         pixel_size;
     Dimension        vm_width, 
                      vm_height;
@@ -416,7 +418,6 @@ static void TVANNOTVolumePropSetDrawableSize(
                 Dimension      width,
                 Dimension      height )
 {
-    XFontSet         fontset;
     TV_INT32         pixel_size;
     Dimension        vm_width, 
                      vm_height;
@@ -443,7 +444,7 @@ static void TVANNOTVolumePropSetDrawableSize(
     }
 
     /*  Determine new location  */
-    sprintf( str, VOLUME_FMT, 100 );
+    sprintf( str, VOLUME_FMT, 100L );
     str_width = XmbTextEscapement( p->fontset, str, strlen(str) );
     extents    = XExtentsOfFontSet( p->fontset );
 
@@ -459,7 +460,6 @@ static void TVANNOTMutePropSetDrawableSize(
                 Dimension      width,
                 Dimension      height )
 {
-    XFontSet         fontset;
     TV_INT32         pixel_size;
     Dimension        vm_width, 
                      vm_height;
@@ -601,7 +601,7 @@ static TV_BOOL TVANNOTStationPropUpdate(
         }
         else
             if ( App_res.station_annot_idonly )
-                sprintf( chan_str, "%s", station->id, station->freq );
+                sprintf( chan_str, "%s", station->id );
             else
                 sprintf( chan_str, "%s (%.2f MHz)", station->id, 
                                                     station->freq );
@@ -623,7 +623,6 @@ static TV_BOOL TVANNOTTunerModePropUpdate(
                    struct timeval *cur_time,
                    TV_ANNOT_PROP  *p )
 {
-    TV_CAPTURE      *c     = &G_glob.capture;
     TV_PREFS        *prefs = &G_glob.prefs;
     char            *str;
 
@@ -696,7 +695,6 @@ static TV_BOOL TVANNOTVolumePropUpdate(
                    struct timeval *cur_time,
                    TV_ANNOT_PROP  *p )
 {
-    TV_CAPTURE      *c = &G_glob.capture;
     TV_INT32         vol;
     char             str[80];
 
@@ -725,7 +723,6 @@ static TV_BOOL TVANNOTMutePropUpdate(
                    struct timeval *cur_time,
                    TV_ANNOT_PROP  *p )
 {
-    TV_CAPTURE      *c = &G_glob.capture;
     TV_BOOL          mute_on;
     char            *str;
 
@@ -777,7 +774,7 @@ TV_BOOL TVANNOTUpdate(
     
     /*  If drawable and its size haven't been set yet, no action  */
     if (( a->drawable == None ) || ( a->geom.w < 0 ))
-        return;
+        return FALSE;
 
     /*  Compute current time (in msec)  */
     gettimeofday( &tv, NULL );
