@@ -249,7 +249,7 @@ static XrmOptionDescRec Cmd_line_options[] = {
    { "-debug"              , RNdebug          , XrmoptionSepArg, NULL        },
    { "-deviceNumber"       , RNdeviceNumber   , XrmoptionSepArg, NULL        },
    { "-inputFormat"        , RNinputFormat    , XrmoptionSepArg, NULL        },
-   { "-aspectlock"         , RNaspectLock     , XrmoptionNoArg , pTRUE       },
+   { "-noaspectlock"       , RNaspectLock     , XrmoptionNoArg , pFALSE      },
    { "-tunerMode"          , RNtunerMode      , XrmoptionSepArg, NULL        },
    { "-defaultChannel"     , RNdefaultChannel , XrmoptionSepArg, NULL        },
    { "-defaultInput"       , RNdefaultInput   , XrmoptionSepArg, NULL        },
@@ -412,7 +412,7 @@ static XtResource Resources[] = {
 
     { RNvideoCnvtScript, RCvideoCnvtScript, XtRString, sizeof(String),
         XtOffsetOf(AppResources, video_cnvt_script ), XtRImmediate,
-        "/usr/X11R6/lib/X11/fxtv/fxtv_cnvt.sh"  },
+        X11BASE "/lib/X11/fxtv/fxtv_cnvt.sh"  },
 
     { RNbswap2Bpp, RCswap, XtRBoolean, sizeof(Boolean),
         XtOffsetOf(AppResources, bswap2Bpp), XtRImmediate,
@@ -526,7 +526,7 @@ static XtResource Resources[] = {
 
 
 #define OPTION_HELP_STR "\
-                    FreeBSD X TV (fxtv), Version " VERS_STR ".  
+                      BSD X TV (fxtv), Version " VERS_STR ".  
                          Written by Randall Hopper
 
 Please mail Fxtv and Bt848 driver-related comments and help requests to the
@@ -550,7 +550,7 @@ Available options:
 
 -tunerMode [cable|antenna]  - Tuner Mode
 -defaultInput <input>       - Startup tuner signal input 
-                                 [tuner|video|svideo|csvideo]
+                                 [tuner|video|svideo|csvideo|dev3]
 -defaultAudioInput <input>  - Startup TV card audio input 
                                  [tuner|external|internal|auto]
 -defaultChannel <#>         - Startup Channel Number
@@ -558,13 +558,13 @@ Available options:
 -antennaStationList <...>   - List of antenna station presets
 -cableFreqSet   <freqset>   - Freq set for cable   (def = cableirc)
                               [nabcst|cableirc|cablehrc|weurope|jpnbcst|
-                               jpncable|xussr|australia]
+                               jpncable|xussr|australia|france]
 -antennaFreqSet <freqset>   - Freq set for antenna (def = nabcst)
 
 -noAudio                    - Suppress playing audio through soundcard
 -dspDevice                  - Override default DSP device   (def=/dev/dsp)
 -mixerDevice                - Override default mixer device (def=/dev/mixer)
--mixerChannel               - Specify mixer channel (line,cd,mic)
+-mixerChannel               - Audio mixer (line,line1/2/3,cd,mic,video)
 
 -stationInWinTitle          - Display station text in window title
 -stationInWinIcon           - Display station text in window icon
@@ -618,7 +618,7 @@ NOTE:  All command line options are accessible as X resources as well.
 
 static String fallback_resources[] = { 
  /*"Fxtv.geometry: +10+10",*/
-   "Fxtv.title:    FreeBSD TV " VERS_STR,
+   "Fxtv.title:    BSD TV " VERS_STR,
    "Fxtv.iconName: FXTV",
 
     /* Menubar appearance */
@@ -658,6 +658,7 @@ static String fallback_resources[] = {
    "*menuBox*inputMenu*videoCmd.label:        Video",
    "*menuBox*inputMenu*svideoCmd.label:       S-Video",
    "*menuBox*inputMenu*csvideoCmd.label:      CS-Video",
+   "*menuBox*inputMenu*dev3.label:            Device 3",
    "*menuBox*inputMenu*tmodeAntenna.label:    Antenna",
    "*menuBox*inputMenu*audInpAuto.label:      Audio Auto",
    "*menuBox*inputMenu*audInpIntern.label:    Audio Internal",
@@ -698,7 +699,7 @@ static String fallback_resources[] = {
    "*toolBox*fullScreenCmd.pixmap:            mini-resize.xpm",
    "*toolBox*channelDnCmd.pixmap:             mini-down.xbm",
    "*toolBox*channelUpCmd.pixmap:             mini-up.xbm",
-   "*toolBox*channelText.width:               44",
+   "*toolBox*channelText.width:               50",
    "*toolBox*channelText.height:              22",
    "*toolBox*spacer.width:                    10",
    "*toolBox*spacer.height:                   2",
