@@ -134,11 +134,6 @@ static TV_RATE_ITEM_DEF    Rate_item_def[] = {
     { 44100                         , "r44100"   },
 };
 
-static TV_INT32            Ffmt_item_def_size = XtNumber( Ffmt_item_def ),
-                           Sfmt_item_def_size = XtNumber( Sfmt_item_def ),
-                           Chan_item_def_size = XtNumber( Chan_item_def ),
-                           Rate_item_def_size = XtNumber( Rate_item_def );
-
 /*      ******************** Forward declarations         ************** */
 /*      ******************** Function Definitions         ************** */
 
@@ -158,8 +153,9 @@ static void SetMenuSelection( Widget menu_btn, TV_UINT32 choice )
                 break;
             }
         if ( i >= XtNumber( Ffmt_item_def ) ) {
-            fprintf( stderr, "TVAUDSAVDIALOGSetSel: Unsupported filefmt %d\n", 
-                             choice );
+            fprintf( stderr, 
+                     "TVAUDSAVDIALOGSetSel: Unsupported filefmt %ld\n", 
+                     choice );
             exit(1);
         }
         Sel_ffmt = choice;
@@ -174,8 +170,9 @@ static void SetMenuSelection( Widget menu_btn, TV_UINT32 choice )
                 break;
             }
         if ( i >= XtNumber( Sfmt_item_def ) ) {
-            fprintf( stderr, "TVAUDSAVDIALOGSetSel: Unsupported sampfmt %d\n", 
-                             choice );
+            fprintf( stderr, 
+                     "TVAUDSAVDIALOGSetSel: Unsupported sampfmt %ld\n", 
+                     choice );
             exit(1);
         }
         Sel_sfmt = choice;
@@ -190,7 +187,7 @@ static void SetMenuSelection( Widget menu_btn, TV_UINT32 choice )
                 break;
             }
         if ( i >= XtNumber( Chan_item_def ) ) {
-            fprintf( stderr, "TVAUDSAVDIALOGSetSel: Unsupported #chan %d\n", 
+            fprintf( stderr, "TVAUDSAVDIALOGSetSel: Unsupported #chan %ld\n", 
                              choice );
             exit(1);
         }
@@ -206,7 +203,7 @@ static void SetMenuSelection( Widget menu_btn, TV_UINT32 choice )
                 break;
             }
         if ( i >= XtNumber( Rate_item_def ) ) {
-            fprintf( stderr, "TVAUDSAVDIALOGSetSel: Unsupported rate %d\n", 
+            fprintf( stderr, "TVAUDSAVDIALOGSetSel: Unsupported rate %ld\n", 
                              choice );
             exit(1);
         }
@@ -345,8 +342,6 @@ static void RecordCmdDoneCB( TV_BOOL aborted, int status, void *cb_data )
     if ( aborted )
         unlink( state->fname_out );
         
-
- RETURN:
     free( state );
     return;
 }
@@ -563,7 +558,6 @@ static void DismissCmdCB( Widget w, XtPointer cl, XtPointer cb )
 /*      identify when the the user aborted the operation.             */
 static TV_BOOL PlaybackCmdCancelTestCB( void *cb_data )
 {
-    TV_AUDIO_CMD_STATE  *state = (TV_AUDIO_CMD_STATE *) cb_data;
 
     return !Playing;
 }
@@ -588,7 +582,6 @@ static void PlaybackCmdDoneCB( TV_BOOL aborted, int status, void *cb_data )
     free( state->cmd );
     free( state->tmpstr );
 
- RETURN:
     free( state );
     return;
 }
@@ -601,19 +594,15 @@ static void PlaybackCmdCB( Widget w, XtPointer cl, XtPointer cb )
     String      filename;
     int         dsp_fd = -1,
                 in_fd = -1;
+#ifdef OLDSTUFF
     ssize_t     read_bytes;
     char        msg[160];
+#endif
     TV_INT32    bps;
     TV_BOOL     mute_on,
                 conv_reqd;
-    char      **cmd,
-               *p;
     TV_INT32    i,j;
-    pid_t       cmd_pid;
-    int         ret,
-                status;
-    TV_BOOL     aborted,
-                cmd_running = FALSE;
+    TV_BOOL     cmd_running = FALSE;
     TVUTIL_PIPE_END end[3] = {{ -1, FALSE }, { -1, FALSE }, { -1 } };
     TV_AUDIO_CMD_STATE *state = NULL;
     char                shell_cmd[ 2*MAXPATHLEN+80 ];
@@ -677,7 +666,7 @@ static void PlaybackCmdCB( Widget w, XtPointer cl, XtPointer cb )
         char *play_cmd;
 
         /*  Grab the right player cmd  */
-        if ( Sel_ffmt = TV_AUDIO_FILE_FMT_MPEG2 )
+        if ( Sel_ffmt == TV_AUDIO_FILE_FMT_MPEG2 )
             play_cmd = App_res.play_cmd_mpeg2;
         else
             play_cmd = App_res.play_cmd_mpeg3;
@@ -709,7 +698,7 @@ static void PlaybackCmdCB( Widget w, XtPointer cl, XtPointer cb )
                 break;
 
         /*  Build Cmd: "sox %s - %s -c %d -r %d -"  */
-        sprintf( shell_cmd, "sox %s - %s -c %d -r %d -",
+        sprintf( shell_cmd, "sox %s - %s -c %d -r %ld -",
                  Ffmt_item_def[j].sox_opt, Sfmt_item_def[i].sox_opt,
                  Sel_stereo ? 2 : 1, Sel_rate );
     }
@@ -1091,8 +1080,6 @@ static void TVAudSavDialogBuild( Widget *dialog_wgt )
 
 void TVAUDSAVDIALOGPopUp()
 {
-    TV_DISPLAY *dpy = &G_glob.display;
-
     /*  Do dialog  */
     if ( Dialog_wgt == NULL )
         TVAudSavDialogBuild( &Dialog_wgt );
