@@ -127,10 +127,13 @@ void TVGLOBInitPrefs( TV_PREFS *p )
     p->cable_num_stations = 0;
     p->ant_num_stations   = 0;
 
-    p->ant_freq_set   = 1;
-    p->cable_freq_set = 1;
-    p->tuner_mode     = TV_TUNER_MODE_ANTENNA;
-    p->afc_mode       = TRUE;
+    p->ant_freq_set    = 1;
+    p->cable_freq_set  = 1;
+    p->tuner_mode      = TV_TUNER_MODE_ANTENNA;
+    p->afc_mode        = TRUE;
+
+    p->last_chan       = 3;               /*  -1 = use last_freq  */
+    p->last_freq       = 0.0;
 }
 
 
