@@ -132,6 +132,11 @@ typedef struct {
 
     TV_TUNER_MODE tuner_mode;
     TV_BOOL       afc_mode;
+
+    TV_BOOL       last_station_is_chan;
+    TV_INT32      last_chan;
+    double        last_freq;
+
 } TV_PREFS;
 
 typedef struct {
