@@ -95,12 +95,12 @@ TV_UINT32 TVRAWVIDEOCalcImageSize(
                    ( pg->samp_size[2] == 8 ));
 
             /* FIXME:  What if X/Y res isn't a multiple of sampling rate?  */
-            printf( "num_pix = %ld\n"
+            /*printf( "num_pix = %ld\n"
                     "pg->samp_int_h = %ld,%ld , %ld,%ld , %ld,%ld\n",
                     num_pix,
                     pg->samp_int_h[0], pg->samp_int_v[0],
                     pg->samp_int_h[1], pg->samp_int_v[1],
-                    pg->samp_int_h[2], pg->samp_int_v[2] );
+                    pg->samp_int_h[2], pg->samp_int_v[2] );*/
 
             return num_pix / (pg->samp_int_h[0] * pg->samp_int_v[0]) +
                    num_pix / (pg->samp_int_h[1] * pg->samp_int_v[1]) +
