@@ -45,7 +45,16 @@
 #include <sys/time.h>
 #include <sys/socket.h>
 #include <sys/un.h>
-#include <machine/mouse.h>
+#ifdef __FreeBSD__
+# include <sys/param.h>
+# if __FreeBSD_version >= 500013
+#  include <sys/mouse.h>
+# else
+#  include <machine/mouse.h>
+# endif
+#else
+# include <machine/mouse.h>
+#endif
 #include <X11/Intrinsic.h>
 #include "tvdebug.h"
 #include "tvutil.h"
@@ -55,8 +64,6 @@
 
 /*      ******************** Local defines                ************** */
 
-#ifndef __NetBSD__
-
 /*  FIXME: Remove this old code someday  */
 #ifdef 0
 #  define OLD_DEV_SYSMOUSE_STUFF
@@ -579,8 +586,6 @@ static void TVX10REMOTEClose( void )
     Remote_fd = -1;
 }
 
-#endif	/* !__NetBSD__ */
-
 
 /**@BEGINFUNC**************************************************************
 
@@ -609,7 +614,6 @@ static void TVX10REMOTEClose( void )
 void TVX10REMOTEOpen( XtAppContext       app_ctx, 
                       TVREMOTE_CB_FUNCT *cb )
 {
-#ifndef __NetBSD__
     int                fd,
                        flags;
 #ifdef OLD_DEV_SYSMOUSE_STUFF
@@ -704,7 +708,6 @@ void TVX10REMOTEOpen( XtAppContext       app_ctx,
 
     /*  Arrange to get called when we exit the app  */
     atexit( TVX10REMOTEClose );
-#endif	/* !__NetBSD__ */
 }
 
 
@@ -733,7 +736,6 @@ void TVX10REMOTEOpen( XtAppContext       app_ctx,
 
 void TVX10REMOTEFlush( void )
 {
-#ifndef __NetBSD__
     unsigned char  btn;
 
     /*  Do nothing if we didn't open the remote  */
@@ -748,7 +750,6 @@ void TVX10REMOTEFlush( void )
             break;
         RMPRINTF(( "TVX10REMOTE:  Flushing buffer (key = %d)\n", btn ));
     }
-#endif	/* !__NetBSD__ */
 }
 
 
