@@ -502,15 +502,18 @@ static void TVSetInitialCaptureDefaults( TV_CAPTURE *c,
         if (( strstr( App_res.def_input, "tuner" ) != NULL ) ||
             ( strstr( App_res.def_input, "TUNER" ) != NULL ))
             video_input_dev = TV_DEVICE_TUNER;
-        else if (( strstr( App_res.def_input, "svideo" ) != NULL ) ||
-                 ( strstr( App_res.def_input, "SVIDEO" ) != NULL ))
-            video_input_dev = TV_DEVICE_SVIDEO;
         else if (( strstr( App_res.def_input, "csvideo" ) != NULL ) ||
                  ( strstr( App_res.def_input, "CSVIDEO" ) != NULL ))
             video_input_dev = TV_DEVICE_CSVIDEO;
+        else if (( strstr( App_res.def_input, "svideo" ) != NULL ) ||
+                 ( strstr( App_res.def_input, "SVIDEO" ) != NULL ))
+            video_input_dev = TV_DEVICE_SVIDEO;
         else if (( strstr( App_res.def_input, "video" ) != NULL ) ||
                  ( strstr( App_res.def_input, "VIDEO" ) != NULL ))
             video_input_dev = TV_DEVICE_VIDEO;
+        else if (( strstr( App_res.def_input, "dev3" ) != NULL ) ||
+                 ( strstr( App_res.def_input, "DEV3" ) != NULL ))
+            video_input_dev = TV_DEVICE_DEV3;
 
         if ( video_input_dev != -1 )
             TVCAPTURESetInputDevice ( c, video_input_dev );
@@ -556,7 +559,6 @@ static void TVSetInitialCaptureDefaults( TV_CAPTURE *c,
     }
 
     /*  Last minute tweaks  */
-
     if (( s.tuner_chan < TV_CHAN_MIN ) || ( s.tuner_chan > TV_CHAN_MAX ))
        TVCAPTURESetTunerChannel( c, 3 );
 
