@@ -102,13 +102,35 @@ static void TVAUDIOSetMixerMask()
     else if ( STREQ( buf, "MIC" ) ) {
         Mixer_dev_id   = SOUND_MIXER_MIC;
         Mixer_dev_mask = SOUND_MASK_MIC;
-        Mixer_dev_name = "LINE";
+        Mixer_dev_name = "MIC";
     }
-    else {
+#ifdef SOUND_MIXER_VIDEO
+    else if ( STREQ( buf, "VIDEO" ) ) {
+       Mixer_dev_id   = SOUND_MIXER_VIDEO;
+       Mixer_dev_mask = SOUND_MASK_VIDEO;
+       Mixer_dev_name = "VIDEO";
+    }
+#endif
+    else if ( STREQ( buf, "LINE" ) ) {
         Mixer_dev_id   = SOUND_MIXER_LINE;
         Mixer_dev_mask = SOUND_MASK_LINE;
         Mixer_dev_name = "LINE";
     }
+    else if ( STREQ( buf, "LINE1" ) ) {
+        Mixer_dev_id   = SOUND_MIXER_LINE1;
+        Mixer_dev_mask = SOUND_MASK_LINE1;
+        Mixer_dev_name = "LINE1";
+    }
+    else if ( STREQ( buf, "LINE2" ) ) {
+        Mixer_dev_id   = SOUND_MIXER_LINE2;
+        Mixer_dev_mask = SOUND_MASK_LINE2;
+        Mixer_dev_name = "LINE2";
+    }
+    else if ( STREQ( buf, "LINE3" ) ) {
+        Mixer_dev_id   = SOUND_MIXER_LINE3;
+        Mixer_dev_mask = SOUND_MASK_LINE3;
+        Mixer_dev_name = "LINES";
+    }
 }
 
 void TVAUDIOResync( TV_BOOL update_gui )
