@@ -36,8 +36,7 @@
 #include <errno.h>
 #include <sys/mman.h>
 #ifdef __NetBSD__
-# include <dev/pci/bt848var.h>
-# include <dev/pci/meteorvar.h>
+# include <dev/ic/bt8xx.h>
 #else
 # include <machine/ioctl_bt848.h>
 #endif
@@ -493,6 +492,9 @@ void TVCAPTURESetInputDevice( TV_CAPTURE *c, TV_INPUT_DEVICE dev )
         case TV_DEVICE_VIDEO   : arg = METEOR_INPUT_DEV0;        break;
         case TV_DEVICE_SVIDEO  : arg = METEOR_INPUT_DEV_SVIDEO;  break;
         case TV_DEVICE_CSVIDEO : arg = METEOR_INPUT_DEV2;        break;
+#ifdef METEOR_INPUT_DEV3
+        case TV_DEVICE_DEV3    : arg = METEOR_INPUT_DEV3;        break;
+#endif
         default :
              fprintf( stderr, "TVCAPTURESetInputDevice(): Bad value %d\n",
                       dev );
@@ -692,6 +694,10 @@ char *TVCAPTUREGetTunerFreqSetName( TV_CAPTURE *c, TV_FREQ_SET set )
 #ifdef CHNLSET_AUSTRALIA
                 case CHNLSET_AUSTRALIA:
                     return "australia";
+#endif
+#ifdef CHNLSET_FRANCE
+                case CHNLSET_FRANCE:
+                    return "france";
 #endif
                 default:
                     return NULL;
@@ -805,6 +811,9 @@ TV_BOOL TVCAPTUREQueryDriverState( TV_CAPTURE *c, TV_DRIVER_STATE *s )
         case METEOR_INPUT_DEV1       : s->input_dev = TV_DEVICE_TUNER  ; break;
         case METEOR_INPUT_DEV_SVIDEO : s->input_dev = TV_DEVICE_SVIDEO ; break;
         case METEOR_INPUT_DEV2       : s->input_dev = TV_DEVICE_CSVIDEO; break;
+#ifdef METEOR_INPUT_DEV3
+        case METEOR_INPUT_DEV3       : s->input_dev = TV_DEVICE_DEV3   ; break;
+#endif
         default :
              fprintf( stderr, "TVCAPTUREQueryDriverState(): Bad INPUT %ld\n",
                       larg );
