@@ -33,7 +33,7 @@
 
 #include <X11/Intrinsic.h>
 #ifdef __NetBSD__
-# include <dev/pci/bt848var.h>
+# include <dev/ic/bt8xx.h>
 #else
 # include <machine/ioctl_meteor.h>
 #endif
@@ -63,6 +63,7 @@ typedef enum {
             TV_DEVICE_VIDEO,
             TV_DEVICE_SVIDEO,
             TV_DEVICE_CSVIDEO,
+            TV_DEVICE_DEV3,
             TV_NUM_INPUT_DEVICES
         } TV_INPUT_DEVICE;
 
