@@ -142,6 +142,7 @@ static TV_MENUITEM_DEF Menuitem_def[] = {
    { TVMI( INPUT,INPUT_VIDEO        ), "videoCmd"      , WC_mcmd , InputCB   },
    { TVMI( INPUT,INPUT_SVIDEO       ), "svideoCmd"     , WC_mcmd , InputCB   },
    { TVMI( INPUT,INPUT_CSVIDEO      ), "csvideoCmd"    , WC_mcmd , InputCB   },
+   { TVMI( INPUT,INPUT_DEV3         ), "dev3Cmd"       , WC_mcmd , InputCB   },
    { TV_MENU_INPUT, -1               , "line"          , WC_mline, NULL      },
    { TVMI( INPUT,TMODE_ANTENNA      ), "tmodeAntenna"  , WC_mcmd , TModeCB   },
    { TVMI( INPUT,TMODE_CABLE        ), "tmodeCable"    , WC_mcmd , TModeCB   },
@@ -311,11 +312,12 @@ static void InputCB( Widget w, XtPointer cl, XtPointer cb )
     TV_MENUITEM_DEF *video  = LookupMenuItemByKey( TV_MENUITEM_INPUT_VIDEO );
     TV_MENUITEM_DEF *svideo = LookupMenuItemByKey( TV_MENUITEM_INPUT_SVIDEO );
     TV_MENUITEM_DEF *csvideo= LookupMenuItemByKey( TV_MENUITEM_INPUT_CSVIDEO );
+    TV_MENUITEM_DEF *dev3   = LookupMenuItemByKey( TV_MENUITEM_INPUT_DEV3 );
     TV_BOOL          on;
     TV_INPUT_DEVICE  dev;
 
     assert(( tuner != NULL ) && ( video != NULL ) && ( svideo != NULL ) && 
-           ( csvideo != NULL));
+           ( csvideo != NULL ) && ( dev3 != NULL ));
 
     if ( w == tuner->wgt )  
         dev = TV_DEVICE_TUNER;
@@ -325,6 +327,8 @@ static void InputCB( Widget w, XtPointer cl, XtPointer cb )
         dev = TV_DEVICE_SVIDEO;
     else if ( w == csvideo->wgt )
         dev = TV_DEVICE_CSVIDEO;
+    else if ( w == dev3->wgt )
+        dev = TV_DEVICE_DEV3;
     else {
         fprintf( stderr, "Unknown input device widget: %s\n", XtName( w ) );
         return;
@@ -676,9 +680,9 @@ static void AspectCB( Widget w, XtPointer cl, XtPointer cb )
 static void AboutCB( Widget w, XtPointer cl, XtPointer cb )
 {
     XUTILDialogPause( TVTOPLEVEL, "About", 
-                      "FreeBSD X TV\n"
+                      "BSD X TV\n"
                       "Version " VERS_STR "\n\n"
-                      "Written by Randall Hopper, 1997-9.",
+                      "Written by Randall Hopper, 1997-2001.",
                       TV_DIALOG_TYPE_OK );
 }
 
@@ -916,12 +920,14 @@ void TVMENUSetSelectedInputDevice( TV_INPUT_DEVICE dev )
     TV_MENUITEM_DEF *video  = LookupMenuItemByKey( TV_MENUITEM_INPUT_VIDEO );
     TV_MENUITEM_DEF *svideo = LookupMenuItemByKey( TV_MENUITEM_INPUT_SVIDEO);
     TV_MENUITEM_DEF *csvideo= LookupMenuItemByKey( TV_MENUITEM_INPUT_CSVIDEO);
+    TV_MENUITEM_DEF *dev3   = LookupMenuItemByKey( TV_MENUITEM_INPUT_DEV3);
     Pixmap           pix;
 
     assert(( tuner != NULL ) && ( video != NULL ) && ( svideo != NULL ) && 
-           ( csvideo != NULL ));
+           ( csvideo != NULL ) && ( dev3 != NULL ));
     assert(( tuner->wgt != NULL ) && (video->wgt != NULL ) &&
-           ( svideo->wgt != NULL) && ( csvideo->wgt != NULL));
+           ( svideo->wgt != NULL) && ( csvideo->wgt != NULL) &&
+           ( dev3->wgt != NULL));
 
     if ( Select_pixmap == None )
         TVMENULoadRadioPixmaps();
@@ -941,6 +947,10 @@ void TVMENUSetSelectedInputDevice( TV_INPUT_DEVICE dev )
     pix = ( dev == TV_DEVICE_CSVIDEO  ) ? Select_pixmap : Unselect_pixmap;
     XtVaSetValues( csvideo->wgt , XtNleftBitmap, pix,
                                  NULL );
+
+    pix = ( dev == TV_DEVICE_DEV3  ) ? Select_pixmap : Unselect_pixmap;
+    XtVaSetValues( dev3->wgt , XtNleftBitmap, pix,
+                               NULL );
 }
 
 void TVMENUSetSelectedAudioInputDevice( TV_AUDIO_INPUT_DEVICE dev )
