@@ -34,21 +34,15 @@
 #include <ctype.h>
 #include <fcntl.h>
 #include <signal.h>
+#include <sys/types.h>
 #if defined(__FreeBSD__)
-#  include <sys/types.h>
+#  include <sys/sysctl.h>
+#elif defined(__bsdi__) || defined(__NetBSD__) || defined(__OpenBSD__)
+#  include <sys/param.h>
 #  include <sys/sysctl.h>
 #elif defined(linux)
 #  include <linux/sysctl.h>
-#elif defined(__bsdi__)
-#  include <sys/types.h>
-#  include <sys/param.h>
-#  include <sys/sysctl.h>
-#elif defined(__NetBSD__)
-#  include <sys/param.h>
-#  include <sys/sysctl.h>
-#  include <sys/wait.h>
 #endif
-#include <sys/types.h>
 #include <sys/wait.h>
 #include <unistd.h>
 #include "tvdefines.h"
@@ -119,6 +113,8 @@ void CleanupChildFileDesc()
     int    mib[2] = { CTL_KERN, KERN_MAXFILES };
 #elif defined(__NetBSD__)
     int    mib[2] = { CTL_KERN, OPEN_MAX };
+#elif defined(__OpenBSD__)
+    int    mib[2] = { CTL_KERN, OPEN_MAX };
 #endif
     int    i;
     size_t len;
