@@ -124,7 +124,7 @@ typedef struct {
 # %s\n\
 #    Fxtv Video/System Stream Conversion Script\n\
 # \n\
-#    Automatically generated by FreeBSD X TV v" VERS_STR "\n\
+#    Automatically generated by BSD X TV v" VERS_STR "\n\
 # \n\
 \n\
 "
@@ -804,9 +804,9 @@ static TV_BOOL WriteVidConvertShScript(
     TV_BOOL      has_path;
 
     /*  Open output script file  */
-    has_path = strchr( "p->fname_base", '/' ) != NULL;
+    has_path = strchr( p->fname_base, '/' ) != NULL;
     sprintf( p->script_fname, SCRIPT_FNAME_FMT, 
-             (has_path ? "./" : ""), p->fname_base );
+             (has_path ? "" : "./"), p->fname_base );
 
     if ( (fp = fopen( p->script_fname, "wt" )) == NULL ) {
         fprintf( stderr, "Failed to open for write: %s\n", p->script_fname );
