@@ -34,7 +34,7 @@
 #  include <machine/soundcard.h>
 #elif defined(linux) || defined(__bsdi__)
 #  include <sys/soundcard.h>
-#elif defined(__NetBSD__)
+#elif defined(__NetBSD__) || defined(__OpenBSD__)
 #  include <soundcard.h>
 #else
 #  error Sorry, I dont know this OS.
