@@ -55,10 +55,8 @@ void XawScrollbarSetThumb( Widget w, float top, float shown );
 
 /*      ******************** Local defines                ************** */
 
-#define XFILESEARCHPATH "XFILESEARCHPATH"
-
 #ifndef FXTV_LIBDIR
-# define FXTV_LIBDIR "/usr/X11R6/lib/X11/fxtv"
+# define FXTV_LIBDIR X11BASE "/lib/X11/fxtv/%T/%N"
 #endif
 
 #define RUNCMD_CHECK_TIMEOUT_MS 200
@@ -199,143 +197,6 @@ Meta<Key>Z:    no-op()\n\
 /*      ******************** Function Definitions         ************** */
 
 
-/**@BEGINFUNC**************************************************************
-
-    Prototype  : void XUTILAugmentXEnv(
-                      char *argv0 )
-
-    Purpose    : Augments XFILESEARCHPATH so bitmap files will be found
-                 at $executable_dir/bitmaps/%N%S or 
-                 /usr/X11R6/lib/X11/fxtv/%N%S or                  
-
-                 Insuff access permissions on directories result in
-                 program exit.
-
-    Programmer : 02-Mar-97  Randall Hopper
-
-    Parameters : argv0 - argv[0] argument to main()
-
-    Returns    : None.
-
-    Globals    : None.
-
- **@ENDFUNC*****************************************************************/
-
-void XUTILAugmentXEnv( char *argv0 )
-{
-    char          old_cwd  [ MAXPATHLEN ],
-                  exec_path[ MAXPATHLEN ] = "",
-                  sys_path [ MAXPATHLEN ],
-                 *p,
-                 *xfsp;
-
-    /*  Get TV executable directory  */
-    if ( getcwd( old_cwd, sizeof(old_cwd) ) == NULL ) {
-        fprintf( stderr, "getcwd() for current dir failed: %s\n", 
-                 strerror( errno ) );
-        exit(1);
-    }
-    exec_path[0] = '\0';
-    strncat( exec_path, argv0, sizeof(exec_path)-1 );
-    if ( (p = strrchr( exec_path, '/' )) != NULL )
-        *p = '\0';
-    else {
-        TV_BOOL found;
-
-        /*  argv0 doesn't indicate exec loc; go find it in $PATH  */
-        if ( (p = getenv( "PATH" )) == NULL ) {
-            fprintf( stderr, 
-                     "Can't find exec directory; skipping X env augment\n" );
-            exec_path[0] = '\0';
-            goto DOAUGMENT;
-        }
-
-        found = FALSE;
-        while ( !found && (*p != '\0') ) {
-            struct stat sb;
-            char   link_path[ MAXPATHLEN ];
-
-            exec_path[0] = '\0';
-            strncat( exec_path, p,
-                     MIN( strcspn( p, ":" ), sizeof(exec_path)-1 ) );
-            strncat( exec_path, "/", sizeof(exec_path)-strlen(exec_path)-1 );
-            strncat( exec_path, argv0,
-                     sizeof(exec_path)-strlen(exec_path)-1 );
-
-            while ( 1 ) /*  follow symlinks  */ {
-
-                if (( access( exec_path, X_OK ) < 0 ) ||
-                    ( lstat( exec_path, &sb ) < 0 ) ||
-                    ( !S_ISLNK(sb.st_mode) && !S_ISREG(sb.st_mode) ))
-                    break;
-
-                if ( S_ISLNK(sb.st_mode) ) {
-                    if ( readlink( exec_path, link_path, 
-                                   sizeof(link_path)-1 ) < 0 )
-                        break;
-                    link_path[ sizeof(link_path)-1 ] = '\0';
-                    strcpy( exec_path, link_path );
-                    continue;
-                }
-                else /* S_IFREG */ {
-                    found = TRUE;
-                    break;
-                }
-            }
-            
-            p += strcspn( p, ":" ) + 1;
-        }
-        if ( !found ) {
-            fprintf( stderr, 
-                     "Can't find exec directory; skipping X env augment\n" );
-            exec_path[0] = '\0';
-            goto DOAUGMENT;
-        }
-        p = strrchr( exec_path, '/' );
-        assert( p != NULL );
-        *p = '\0';
-    }
-
-    /*  Make sure exec directory path is absolute  */
-    if ( chdir( exec_path ) ) {
-        fprintf( stderr, "chdir() to '%s' failed: %s\n", 
-                 exec_path, strerror( errno ) );
-        exit(1);
-    }
-    if ( getcwd( exec_path, sizeof(exec_path) ) == NULL ) {
-        fprintf( stderr, "getcwd() for exec dir failed: %s\n", 
-                 strerror( errno ) );
-        exit(1);
-    }
-    if ( chdir( old_cwd ) ) {
-        fprintf( stderr, "chdir() back to current dir failed: %s\n", 
-                 strerror( errno ) );
-        exit(1);
-    }
-
- DOAUGMENT:
-
-    sys_path[0] = '\0';
-    strncat( sys_path, FXTV_LIBDIR, sizeof(sys_path)-1 );
-    strncat( sys_path, "/%T/%N", sizeof(sys_path)-strlen(sys_path)-1 );
-
-    /*  And append path to bitmaps (exec_dir/bitmaps/%N%S) */
-    strncat( exec_path, "/%T/%N", sizeof(exec_path)-strlen(exec_path)-1 );
-    xfsp = getenv( XFILESEARCHPATH );
-    if ( xfsp == NULL )
-        xfsp = "";
-
-    if ( (p = malloc( strlen(XFILESEARCHPATH) + strlen(xfsp) +
-                      strlen(exec_path) +strlen(sys_path) + 4 )) == NULL )
-        TVUTILOutOfMemory();
-
-    if ( xfsp[0] == '\0' )
-        sprintf( p, "%s=%s:%s", XFILESEARCHPATH, exec_path, sys_path );
-    else
-        sprintf( p, "%s=%s:%s:%s", XFILESEARCHPATH, xfsp, exec_path, sys_path);
-    putenv( p );
-}
-
 /**@BEGINFUNC**************************************************************
 
     Prototype  : TV_BOOL XUTILBitmapLoad(
@@ -361,22 +222,18 @@ TV_BOOL XUTILBitmapLoad( char   *bitmap_file,
                       Widget  wgt,
                       Pixmap *pixmap )
 {
-    char           *xfsp;
     char           *pixmap_path = NULL;
     unsigned        width,
                     height;
     int             x_hot,
                     y_hot;
 
-    /****************************************************************/
-    /*  Look for the pixmap file in the standard places where Xt/   */
-    /*  Motif would look for it.                                    */
-    /****************************************************************/
-    if ( (xfsp = getenv( "XFILESEARCHPATH" )) == NULL )
-        xfsp = ".";
+    /********************************************/
+    /*  Look for the pixmap file in FXTV_LIBDIR */
+    /********************************************/
 
     pixmap_path = XtResolvePathname( XtDisplay(wgt), "bitmaps", bitmap_file, 
-                                     NULL, xfsp, NULL, 0, NULL);
+                                     NULL, FXTV_LIBDIR, NULL, 0, NULL);
 
     if ( pixmap_path == NULL ) {
         fprintf( stderr, "Failed to find bitmap '%s'\n", bitmap_file );
@@ -462,20 +319,15 @@ TV_BOOL XUTILPixmapLoad( char    *pixmap_file,
                     height;
     XGCValues       gcv;
     GC              gc;
-    char           *xfsp;
 
     if ( pixmap == NULL )
         return False;
 
-    /****************************************************************/
-    /*  Look for the pixmap file in the standard places where Xt/   */
-    /*  Motif would look for it.                                    */
-    /****************************************************************/
-    if ( (xfsp = getenv( "XFILESEARCHPATH" )) == NULL )
-        xfsp = ".";
-
+    /********************************************/
+    /*  Look for the pixmap file in FXTV_LIBDIR */
+    /********************************************/
     pixmap_path = XtResolvePathname( XtDisplay(wgt), "bitmaps", pixmap_file, 
-                                     NULL, xfsp, NULL, 0, NULL);
+                                     NULL, FXTV_LIBDIR, NULL, 0, NULL);
 
     if ( pixmap_path == NULL ) {
         fprintf( stderr, "Failed to find bitmap/pixmap '%s'\n", pixmap_file );
@@ -658,15 +510,14 @@ void XUTILGetVisualBpp(
         TV_INT32  Bpp_pixmap;
         TV_INT32  Bpp_fbuffer;
     } *Vlist = NULL;
-    static Vlist_len = 0;
+    static int Vlist_len = 0;
 
     TV_INT32   i,
                Bpp = 0;
-    XImage    *ximg;
 
     /*  Look up cached value  */
     for ( i = 0; i < Vlist_len; i++ )
-        if ( Vlist[i].visualid = vi->visualid )
+        if ( Vlist[i].visualid == vi->visualid )
             break;
 
     /*  Didn't have a cached value?  Go figure it out.  */
@@ -813,7 +664,6 @@ void XUTILDialogSmartPosition(
               d_y,
               m_ul[2],
               m_lr[2];
-    Display  *display = XtDisplay( main_wgt );
     Screen   *screen  = XtScreen ( main_wgt );
 
     XtVaGetValues( dialog_wgt, XtNwidth , &d_width,
@@ -950,9 +800,6 @@ Widget XUTILDialogBuild( Widget toplevel,
 TV_INT32 XUTILDialogPause( Widget toplevel,
                            char title[], char msg[], TV_DIALOG_TYPE type )
 {
-    Position    x,
-                y;
-    Dimension   width;
     Widget      shell;
 
     /*  Sanity check  */
@@ -996,6 +843,8 @@ TV_INT32 XUTILDialogPause( Widget toplevel,
                  (mask[0] << shift[0]) | (mask[1] << shift[1]) | 
                  (mask[2] << shift[2])
 
+                 FIXME: Duplicated in videolib
+
     Programmer : 07-Mar-97  Randall Hopper
 
     Parameters : rel_mask- I: R/G/B shifted mask for each compoent
@@ -1053,6 +902,8 @@ static void XUTILGetPixelGeomInfo(
     Purpose    : Given a source pixel mask and a destination pixel mask,
                  determines the shifts and masks necessary to map the
                  source pixel geometry to the destination.
+                 
+                 FIXME: Duplicated in videolib
 
     Programmer : 29-Mar-97  Randall Hopper
 
@@ -1607,3 +1458,88 @@ TV_BOOL XUTILXServerIsLocal( Display *display )
 }
 
 
+/**@BEGINFUNC**************************************************************
+
+    Prototype  : void XUTILDetermineFrameBufferVisual(
+                      Display      *display,
+                      int           screen,
+                      XVisualInfo **fb_visual )
+
+    Purpose    : Determine which visual corresponds the native format
+                 of the frame buffer.
+                 
+    Programmer : 16-Oct-99  Randall Hopper
+
+    Parameters : display   - I: X display
+                 screen    - I: X screen
+                 fb_visual - O: XVisualInfo for frame buffer visual
+
+    Returns    : None.
+
+    Globals    : None.
+
+ **@ENDFUNC*****************************************************************/
+
+void XUTILDetermineFrameBufferVisual( Display      *display,
+                                      int           screen,
+                                      XVisualInfo **fb_visual )
+{
+    XVisualInfo          vinfo_pref;
+    XVisualInfo         *visual;
+    int                  num_visuals;
+    TV_INT32             Bpp_pixmap_best  = -1,
+                         Bpp_fbuffer_best = -1,
+                         best_i           = -1,
+                         i;
+
+    /**********************************************************************/
+    /*  FIXME:  This algorithm is heuristic and prone to failure.  Until  */
+    /*    we have an enhanced XFree86 DGA 2.0 to tell us, we simply       */
+    /*    assume the frame buffer visual is the one with the most         */
+    /*    impressive pixel format.                                        */
+    /**********************************************************************/
+
+    vinfo_pref.screen = screen;
+    visual = XGetVisualInfo( display, VisualScreenMask, &vinfo_pref, 
+                             &num_visuals );
+    if ( num_visuals == 0 ) {
+        fprintf( stderr, "XGetVisualInfo() says no visuals available!\n" );
+        exit(1);
+    }
+    
+    for ( i = 0; i < num_visuals; i++ ) {
+        TV_INT32     Bpp_pixmap,
+                     Bpp_fbuffer;
+
+        XUTILGetVisualBpp( display, &visual[i], &Bpp_pixmap, &Bpp_fbuffer );
+        if ( (( visual[i].class == PseudoColor ) ||
+              ( visual[i].class == TrueColor   )) &&
+             (( Bpp_pixmap  > Bpp_pixmap_best ) ||
+              ( Bpp_fbuffer > Bpp_fbuffer_best )) ) {
+            Bpp_pixmap_best  = Bpp_pixmap;
+            Bpp_fbuffer_best = Bpp_fbuffer;
+            best_i           = i;
+        }
+    }
+
+    if ( best_i >= 0 )
+        *fb_visual = &visual[ best_i ];
+    else {
+        Visual *def_vis;
+
+        fprintf( stderr, "XUTILDetermineFrameBufferVisual failed.  "
+                         "Falling back to default visual.\n" );
+
+        def_vis = DefaultVisual( display, screen );
+        vinfo_pref.screen   = screen;
+        vinfo_pref.visualid = XVisualIDFromVisual( def_vis );
+
+        *fb_visual = XGetVisualInfo( display, 
+                                     VisualScreenMask | VisualIDMask, 
+                                     &vinfo_pref, &num_visuals );
+        if ( num_visuals != 1 ) {
+            fprintf( stderr, "XGetVisualInfo() failed for default visual\n" );
+            exit(1);
+        }
+    }
+}
